@@ -26,6 +26,7 @@ from pyomo.common.collections import Mapping
 from pyomo.common.deprecation import deprecated, deprecation_warning, RenamedClass
 from pyomo.common.fileutils import StreamIndenter
 from pyomo.common.log import is_debug_set
+from pyomo.common.sorting import sorted_robust
 from pyomo.common.timing import ConstructionTimer
 from pyomo.core.base.component import (
     Component, ActiveComponentData, ModelComponentFactory,
@@ -33,11 +34,10 @@ from pyomo.core.base.component import (
 from pyomo.core.base.componentuid import ComponentUID
 from pyomo.core.base.set import GlobalSetBase, _SetDataBase
 from pyomo.core.base.var import Var
-from pyomo.core.base.util import Initializer
+from pyomo.core.base.initializer import Initializer
 from pyomo.core.base.indexed_component import (
     ActiveIndexedComponent, UnindexedComponent_set,
 )
-from pyomo.core.base.misc import sorted_robust
 
 from pyomo.opt.base import ProblemFormat, guess_format
 from pyomo.opt import WriterFactory
@@ -212,8 +212,7 @@ def _levelWalker(list_of_generators):
     generators.
     """
     for gen in list_of_generators:
-        for item in gen:
-            yield item
+        yield from gen
 
 
 class _BlockConstruction(object):
@@ -969,8 +968,8 @@ component, use the block del_component() and add_component() methods.
         #
         # Set the name and parent pointer of this component.
         #
-        val._name = name
         val._parent = weakref.ref(self)
+        val._name = name
         #
         # We want to add the temporary / implicit sets first so that
         # they get constructed before this component
@@ -1401,12 +1400,10 @@ Components must now specify their rules explicitly using 'rule=' keywords.""" %
         generator recursively descends into sub-blocks.
         """
         if not descend_into:
-            for x in self.component_map(ctype, active, sort).values():
-                yield x
+            yield from self.component_map(ctype, active, sort).values()
             return
         for _block in self.block_data_objects(active, sort, descend_into, descent_order):
-            for x in _block.component_map(ctype, active, sort).values():
-                yield x
+            yield from _block.component_map(ctype, active, sort).values()
 
     def component_data_objects(self,
                                ctype=None,
@@ -1460,10 +1457,9 @@ Components must now specify their rules explicitly using 'rule=' keywords.""" %
             block_generator = (self,)
 
         for _block in block_generator:
-            for x in _block._component_data_iter(ctype=ctype,
-                                                 active=active,
-                                                 sort=sort):
-                yield x
+            yield from _block._component_data_iter(ctype=ctype,
+                                                   active=active,
+                                                   sort=sort)
 
     @deprecated("The all_blocks method is deprecated.  "
                 "Use the Block.block_data_objects() method.",
